/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package org.jab.docsearch.utils;

import org.apache.commons.lang3.StringUtils;
import org.jab.docsearch.constants.FileType;

/**
 * File type utils
 *
 * @version $Id: FileTypeUtils.java 281 2020-11-11 16:45:40Z henschel $
 */
public final class FileTypeUtils {

    /**
     * Checks whether file type is text
     *
     * @param file  filename
     * @return      true for file ending in .txt etc...
     */
    public static boolean isFileTypeText(final String file) {
        int lastDotIndex = StringUtils.lastIndexOf(file, '.');

        return (lastDotIndex >= 0 &&
                FileType.fromValue(file.substring(lastDotIndex + 1)) == FileType.TEXT);
    }


    /**
     * Checks whether file type is HTML
     *
     * @param file  filename
     * @return      true for links ending in .htm, .shtm, .asp, .jsp, etc...
     */
    public static boolean isFileTypeHTML(final String file) {
        int lastDotIndex = StringUtils.lastIndexOf(file, '.');

        return (lastDotIndex >= 0 &&
                FileType.fromValue(file.substring(lastDotIndex + 1)) == FileType.HTML);
    }
}
